# variables that can be passed on the command line:
# - willConvertLinks - convert local .gmi links to .html

# this converts the git history into an ATOM feed
# the history should be passed in a specific format. for example
# 2023-05-18T15:36:40+06:00	"added feed.txt, as well as scripts/new_feed_entry.el. i will soon generate my ATOM feeds using feed.txt instead of src/feed.ass"
# feed.txt
# scripts/new_feed_entry.el 

BEGIN {
	FS = "[\t ]*"
	body = ""
	lastUpdated = ""
	documentUuid = ""
}

/^[^#]/ {
	date = $1
	$1 = ""
	title = $0
	sub("^[\t ]*", "", title)

	getline
	while ($0 !~ "^[ \t]*$") {
		body = body sprintf("\
<entry>\n\
	<title>%s</title>\n\
	<link href='%s' />\n\
	<id>urn:uuid:%s</id>\n\
	<updated>%s</updated>\n\
	<summary>%s</summary>\n\
</entry>\n", title " (" $0 ")", $0, uuid, date, title)
		
		if (lastUpdated == "") lastUpdated = date
		if (getline != 1) break
	}
}

END {
	sprintf("uuidgen -s -n @x500 -N \"techn0path\"") | getline documentUuid

	printf "<?xml version='1.0' encoding='UTF-8' ?>\n\
<feed xmlns='http://www.w3.org/2005/Atom'>\n\
	<title>techn0path</title>\n\
	<link rel='self' href='' />\n\
	<author>\n\
		<name>techn0path</name>\n\
	</author>\n\
	<updated>%s</updated>\n\
	<id>urn:uuid:%s</id>\n\
%s\n\
</feed>\n", \
	lastUpdated, \
	documentUuid, \
	body
}
